@@ -36,7 +36,7 @@ NULL
 #' @importFrom fs path file_access file_exists dir_ls file_info path_file path_ext
 #' @importFrom tibble as_tibble
 #'
-fileGetter <- function(roots, restrictions, filetypes, pattern, hidden=FALSE) {
+fileGetter <- function(roots, restrictions, filetypes, pattern, hidden = FALSE) {
   if (missing(filetypes)) {
     filetypes <- NULL
   } else if (is.function(filetypes)) {
@@ -74,10 +74,10 @@ fileGetter <- function(roots, restrictions, filetypes, pattern, hidden=FALSE) {
     fileInfo <- suppressWarnings(file_info(files, fail = FALSE))
     fileInfo$filename <- path_file(files)
     fileInfo$extension <- tolower(path_ext(files))
-    fileInfo$isdir <- fileInfo$type %in% c("directory", "symlink")
-    fileInfo$mtime <- format(fileInfo$modification_time, format = "%Y-%m-%d-%H-%M")
-    fileInfo$ctime <- format(fileInfo$birth_time, format = "%Y-%m-%d-%H-%M")
-    fileInfo$atime <- format(fileInfo$access_time, format = "%Y-%m-%d-%H-%M")
+    fileInfo$isdir <- dir.exists(files)
+    fileInfo$mtime <- as.integer(fileInfo$modification_time) * 1000
+    fileInfo$ctime <- as.integer(fileInfo$birth_time) * 1000
+    fileInfo$atime <- as.integer(fileInfo$access_time) * 1000
     
     if (!is.null(filetypes)) {
       matchedFiles <- tolower(fileInfo$extension) %in% tolower(filetypes) & fileInfo$extension != ""
@@ -182,7 +182,7 @@ fileGetter <- function(roots, restrictions, filetypes, pattern, hidden=FALSE) {
 #'
 #' @family shinyFiles
 #'
-#' @importFrom shiny observe invalidateLater req
+#' @importFrom shiny observe invalidateLater req observeEvent
 #' @importFrom fs path 
 #'
 #' @export
@@ -192,7 +192,7 @@ shinyFileChoose <- function(input, id, updateFreq = 0, session = getSession(),
   currentDir <- list()
   clientId <- session$ns(id)
 
-  observe({
+  sendDirectoryData <- function(message) {
     req(input[[id]])
     dir <- input[[paste0(id, "-modal")]]
     if (is.null(dir) || is.na(dir)) {
@@ -205,8 +205,18 @@ shinyFileChoose <- function(input, id, updateFreq = 0, session = getSession(),
     fileGet <- do.call(fileGetter, list(...))
     newDir <- do.call(fileGet, dir)
     currentDir <<- newDir
-    session$sendCustomMessage("shinyFiles", list(id = clientId, dir = newDir))
+    session$sendCustomMessage(message, list(id = clientId, dir = newDir))
     if (updateFreq > 0) invalidateLater(updateFreq, session)
+  }
+
+  observe({
+    sendDirectoryData("shinyFiles")
+  })
+
+  observeEvent(input[[paste0(id, "-refresh")]], {
+    if (!is.null(input[[paste0(id, "-refresh")]])) {
+      sendDirectoryData("shinyFiles-refresh")
+    }
   })
 }
 
